@@ -51,16 +51,16 @@ class Selenium(Scraper):
 
         url = config.get(section='SELENIUM', key='url')
 
-        prefs = {'profile.default_content_setting_values': {'cookies': 2, 'images': 2, 'javascript': 2, 
-                                    'plugins': 2, 'popups': 2, 'geolocation': 2, 
-                                    'notifications': 2, 'auto_select_certificate': 2, 'fullscreen': 2, 
-                                    'mouselock': 2, 'mixed_script': 2, 'media_stream': 2, 
-                                    'media_stream_mic': 2, 'media_stream_camera': 2, 'protocol_handlers': 2, 
-                                    'ppapi_broker': 2, 'automatic_downloads': 2, 'midi_sysex': 2, 
-                                    'push_messaging': 2, 'ssl_cert_decisions': 2, 'metro_switch_to_desktop': 2, 
-                                    'protected_media_identifier': 2, 'app_banner': 2, 'site_engagement': 2, 
-                                    'durable_storage': 2}}
-        options.add_experimental_option('prefs', prefs)
+        # prefs = {'profile.default_content_setting_values': {'cookies': 2, 'images': 2, 'javascript': 2, 
+        #                             'plugins': 2, 'popups': 2, 'geolocation': 2, 
+        #                             'notifications': 2, 'auto_select_certificate': 2, 'fullscreen': 2, 
+        #                             'mouselock': 2, 'mixed_script': 2, 'media_stream': 2, 
+        #                             'media_stream_mic': 2, 'media_stream_camera': 2, 'protocol_handlers': 2, 
+        #                             'ppapi_broker': 2, 'automatic_downloads': 2, 'midi_sysex': 2, 
+        #                             'push_messaging': 2, 'ssl_cert_decisions': 2, 'metro_switch_to_desktop': 2, 
+        #                             'protected_media_identifier': 2, 'app_banner': 2, 'site_engagement': 2, 
+        #                             'durable_storage': 2}}
+        # options.add_experimental_option('prefs', prefs)
 
         if url is not None:
             self.driver = webdriver.Remote(command_executor=f'{url}', desired_capabilities={'browserName': 'chrome'}, options=options)
